@@ -142,6 +142,15 @@ class AWebspaceSettings(BaseSetting, ClusterableModel):
         help_text="Text qui apparait en haut des articles en lien"
     )
 
+    multi_header = models.BooleanField(
+        default=True,
+        help_text="Ajoute le choix des langages dans le header"
+    )
+    multi_footer = models.BooleanField(
+        default=True,
+        help_text="Ajoute le choix des langages dans le footer"
+    )
+
     general_panels = [
         FieldPanel('language'),
         FieldPanel('ga_code'),
@@ -189,12 +198,18 @@ class AWebspaceSettings(BaseSetting, ClusterableModel):
         InlinePanel("founders", label="Founders")
     ]
 
+    multi_panels = [
+        FieldPanel('multi_header'),
+        FieldPanel('multi_footer'),
+    ]
+
     edit_handler = TabbedInterface([
         ObjectList(general_panels, heading='General'),
         ObjectList(brand_tab_panels, heading='Brand'),
         ObjectList(organization_panels, heading='Organization'),
         ObjectList(socials_panels, heading='Socials'),
         ObjectList(blog_panels, heading='Articles'),
+        ObjectList(multi_panels, heading='Multilingue'),
     ])
 
     class Meta:
