@@ -10,21 +10,28 @@ register = template.Library()
 logger = logging.getLogger('forms')
 
 
+@register.filter
 def ico(icon, theme):
-    if theme == 'space':
-        return icon['space']
-    return icon['light']
-
+    if icon:
+        if theme == 'space' or theme == 'space-inverse':
+            return icon['space']
+        return icon['light']
+    return None
 
+@register.filter
 def ico_astro(icons, level):
     return icons['astro_level_%s' % level]
 
 
+@register.filter
 def ico_get(icons, key):
-    return icons[key]
+    try:
+        return icons[key]
+    except:
+        return None
 
 
-@register.filter(is_safe=False)
+@register.filter
 def plur(value, arg='s'):
     if ',' not in arg:
         arg = ',' + arg
@@ -44,6 +51,7 @@ def plur(value, arg='s'):
     return ''
 
 
+@register.filter
 def embed(url):
     try:
         embed = get_embed(url)
@@ -55,14 +63,17 @@ def embed(url):
         return "<iframe class='lazy' data-src='%s'></iframe>" % url
 
 
+@register.filter
 def strfix(value):
     return value.replace('\n', '')
 
 
+@register.filter
 def klass(ob):
     return re.sub('(((?<=[a-z])[A-Z])|([A-Z](?![A-Z]|$)))', '-\\1', ob.__class__.__name__).lower().strip('-')
 
 
+@register.filter
 def cached_form(form, request):
     if form:
         if 'current_form_id' in request.session and request.session['current_form_id'] and form.id == request.session['current_form_id']:
@@ -74,18 +85,8 @@ def cached_form(form, request):
     return []
 
 
+@register.filter
 def debug(item):
     import pdb
     pdb.set_trace()
     return
-
-
-register.filter('ico', ico)
-register.filter('ico_astro', ico_astro)
-register.filter('ico_get', ico_get)
-register.filter('plur', plur)
-register.filter('embed', embed)
-register.filter('strfix', strfix)
-register.filter('klass', klass)
-register.filter('cached_form', cached_form)
-register.filter('debug', debug)
