@@ -8,12 +8,16 @@ from wagtail.admin.rich_text.converters.html_to_contentstate import InlineStyleE
 from django.urls import include, path, reverse
 from django.utils.translation import gettext_lazy as _
 from wagtail.admin.menu import MenuItem
-from wagtail.core import hooks
 from webspace.cms.bakery import urls as urls_bakery
+from draftjs_exporter.dom import DOM
+from wagtail.core import hooks
+from wagtail.admin.rich_text.converters.html_to_contentstate import ExternalLinkElementHandler, PageLinkElementHandler
 
 NOTHING_RE = re.compile('a^')
 
 
+#  RichText Mark
+
 @hooks.register('register_rich_text_features')
 def register_mark_feature(features):
     feature_name = 'mark'
@@ -39,6 +43,8 @@ def register_mark_feature(features):
     features.default_features.append('mark')
 
 
+#  RichText Code Blocks
+
 class PreformattedTextElementHandler(BlockElementHandler):
     """
     BlockElementHandler that preserves all whitespace.
@@ -84,6 +90,26 @@ def register_code_block_feature(features):
     features.default_features.append(feature_name)
 
 
+#  RichText Eternal Links
+
+from django.utils.html import escape
+from wagtail.core.rich_text import LinkHandler
+
+
+class NoFollowExternalLinkHandler(LinkHandler):
+    identifier = 'external'
+
+    @classmethod
+    def expand_db_attributes(cls, attrs):
+        href = attrs["href"]
+        return '<a href="%s" rel="nofollow">' % escape(href)
+
+
+@hooks.register('register_rich_text_features')
+def register_external_link(features):
+    features.register_link_type(NoFollowExternalLinkHandler)
+
+
 #  Bakery
 
 
