@@ -6,10 +6,13 @@ from wagtail.admin import urls as wagtailadmin_urls
 from wagtail.core import urls as wagtail_urls
 from wagtail.contrib.sitemaps.views import sitemap
 from wagtail_feeds.feeds import BasicFeed, ExtendedFeed
+from wagtail.core import views
 
 from .views import robots, error_404
 from .cms.amp import urls as wagtail_amp_urls
 
+views.serve.csrf_exempt = True
+
 urlpatterns = [
     url(r'^robots\.txt$', robots),
     url(r'^test$', error_404),
@@ -18,7 +21,6 @@ urlpatterns = [
     url(r'^wagtail_WSQtYMxmgLV9iIn6VE3An1VxpH9aoOUeg/', include(wagtailadmin_urls)),
     url(r"^amp/", include(wagtail_amp_urls)),
     url(r"^", include(wagtail_urls)),
-
     url(r'^articles/rss/basic$', BasicFeed(), name='basic_feed'),
     url(r'^articles/rss/extended$', ExtendedFeed(), name='extended_feed'),
 ] + static(settings.MEDIA_URL, document_root=settings.MEDIA_ROOT)
